###########################################################################
# Insert one TMS320C5500 CPU into JTAG chain
# with emulator as parent 
###########################################################################

# Override default parameter from emulator's definition script
# Enable adaptive TCK generation
xds param $EMU sepk.pod_aclk_enable YES

# Configure routers for adaptive clocking mode
xds param $EMU router.adaptive_tclk YES

# Skip polling on routers
xds param $EMU router.skip_polling YES

# Insert ICEPICK-C router into JTAG-path
set router [xds add ICEPICK-C $EMU]
xds param $router router.subpaths 3

# Define router port's
set etb_port [xds add PORT $router]
xds param $etb_port router.address 19
xds param $etb_port router.default no
xds param $etb_port router.custom no

set arm_port [xds add PORT $router]
xds param $arm_port router.address 18
xds param $arm_port router.default no
xds param $arm_port router.custom no

set dsp_port [xds add PORT $router]
xds param $dsp_port router.address 17
xds param $dsp_port router.default no
xds param $dsp_port router.custom no

# Connect cores to each router's port
set DSP   [xds add TMS320C64PLUS $dsp_port]
set ARM   [xds add ARM9 $arm_port]
set ETB11 [xds add GENERIC $etb_port]
xds param $ETB11 generic.irbits 4

###########################################################################
# Select $DSP CPU as target device DEV, to which flash/EEPROM is connected
###########################################################################
set DEV $DSP

###########################################################################
# CPU clock frequency
###########################################################################
set cpu_clock    240000000
set periph_clock 240000000

###########################################################################
# for SPI-interfaced FLASH IC's
# set information on CS signal

# CS signal connected to dedicated CS pin
set cs_port_address "auto"
# CS signal number (for dedicated CS outputs)
set cs_number 0
# CS signal port is in mempage 0
#set cs_port_mempage 0
# CS signal port width (0 - 8-bit, 1 - 16-bit, 2 - 32-bit)
#set cs_port_width 2
# CS signal bit is 0x0001
#set cs_port_bit 0x0001
# CS signal polarity is 0, active low
#set cs_port_polarity 0


###########################################################################
# change this proc according to schematic of your
# board to initialize all of the environment of EEPROM/Flash
# for correct programming
###########################################################################
proc UserInitCPUEnv { dev } {

  upvar 1 flash_type flash_type

}

###########################################################################
# change this proc according to schematic of your
# board to reset all of the environment of EEPROM/Flash
# for normal operation after programming
###########################################################################
proc UserFinishCPUEnv { dev } {

  upvar 1 flash_type flash_type

}
