/*
   Data definitions
*/

#include "comdef.h"

/* common variables */
volatile uint32 command;        /* Command code */
volatile uint32 status;         /* Status of operation */
volatile uint32 address;        /* Address for operation */
volatile uint32 length;         /* Length of data in buffer */
volatile uint32 pagelen;        /* Page size of IC for page-based programming */
volatile uint32 sectorlen;		/* Sector size for some flash types */
volatile uint32 flash_type;     /* Type of IC */
volatile uint32 flash_subtype;  /* Subtype of IC */
volatile uint32 width;          /* width of IC's data 0 - 8 bit; 1 - 16 bit */
volatile uint32 buffer_size;    /* PC-read-only buffer size */
volatile uint32 iftype;			/* 0 - external data bus; 1 - I2C; 2 - MCBSP in SPI mode */
volatile uint32 ctrlr_base;     /* Base address of controller, by which communication with 
                                   flash are performed in CPU's address space */
volatile uint32 flash_size;     /* Flash size*/
volatile uint32 fProgKeys;       /* set to 0x12345678 to enable flash keys programming */

/* classic flash interface specific */
volatile uint32 dbus_shift;     /* Position of first bit of IC's dbus on CPU dbus*/
volatile uint32 base_address;   /* Start address of IC in CPU's address spase */
volatile uint32 cmd_offsets[2]; /* Offsets for even and odd commands */
volatile uint32 xbus_width;     /* Width of external memory interface */
volatile uint32 word_width;     /* Width of one word of data per one CPU address */

/* Common variables for serial EEPROM's */
volatile uint32 c_addr_bytes;   /* count of address bytes for serial EEPROM */

/* I2C EEPROM interface specific */
volatile uint32 i2c_addr;       /* I2C Address byte */
volatile uint32 i2c_addr_mask;  /* mask for P0..Pn bits in I2C address field */

/* SPI FLASH & EEPROM interface specific */
volatile uint32 cs_port_address;  /* Address of port with CS signal */
volatile uint32 cs_port_mempage;  /* Memory page of port (CODE/DATA/IO)*/
volatile uint32 cs_port_width;    /* Width of port */
volatile uint32 cs_port_bit;      /* bit mask of bit */
volatile uint32 cs_port_polarity; /* polarity of CS signal. 0 - ~bit drives active level, 1 - bit */

/* Internal flash specific */
#if defined(__TMS470__)|| \
    defined(__TMS320C28XX__)

volatile uint32 sectors;         /* Count of sectors */
volatile uint32 sector_def[32];  /* sector/bank table. High 8 bytes - bank, low 24 - size of sector*/
volatile uint32 flsh_passwd[4];   /* Password for flash programming enable */

#endif

/* constant for target endianess check */
const uint32 endian_test = 0x12345678;  /* PC-read-only - for endianess detection */

/* Buffer for data transfer from PC */
#if !defined(_TMS320C3x) /* TMS320C30 compiler needs this directive in include file */
  #pragma DATA_SECTION(buffer, ".buf")
#endif
volatile uint32 buffer[BUF_SIZE/4];

/* Internal buffer for receiving page while verifying */
volatile uint32 rcvbuf[RCVBUF_SIZE/4];

