#include "../src/comdef.h"
 
uint16 GetByte (void* buf, uint16 ofs)
{                  

  uint32 base = (uint32) buf;    

#if defined(_TMS320C3x)
  /* 0ne 32-bit word per address */
  uint32 real_word;
  real_word = *(uint32*)(base + (ofs >> 2));
  real_word = 0xFF & (real_word >> ((ofs & 3) << 3));
#elif defined(__TMS320C55X__)
  /* 0ne 16-bit word per address, big endian */
  uint16 real_word;
  real_word = *(uint16*)(base + (ofs >> 1));
  real_word = 0xFF & (real_word >> (((ofs & 1) ^ 1) << 3));
#elif defined(__TMS320C28XX__)
  /* 0ne 16-bit word per address, little endian */
  uint16 real_word;
  real_word = *(uint16*)(base + (ofs >> 1));
  real_word = 0xFF & (real_word >> ((ofs & 1) << 3));
#else
  /* 0ne 8-bit word per address */
  uint16 real_word;
  real_word = (uint16) (*(uint8*)(base + ofs));
#endif

  return real_word;

}

void PutByte (void* buf, uint16 ofs, uint16 byte)
{                       

  uint32 base = (uint32) buf;    

#if defined(_TMS320C3x)
  /* 0ne 32-bit word per address */
  /* read word */
  uint32 word;
  uint16 sh = (ofs & 3) << 3;
  word = *(uint32*)(base + (ofs >> 2));
  /* mask bit field */
  word &= ~(0xFF << sh);
  /* put byte into word */
  word |= (0xFF & byte) << sh;
  /* put word back into memory */
  *(uint32*)(base + (ofs >> 2)) = word;
#elif defined(__TMS320C55X__)
  /* 0ne 16-bit word per address, big endian */
  /* read word */
  uint16 word;
  uint16 sh = ((ofs & 1) ^ 1) << 3;
  word = *(uint16*)(base + (ofs >> 1));
  /* mask bit field */
  word &= ~(0xFF << sh);
  /* put byte into word */
  word |= (0xFF & byte) << sh;
  /* put word back into memory */
  *(uint16*)(base + (ofs >> 1)) = word;
#elif defined(__TMS320C28XX__)
  /* 0ne 16-bit word per address, little endian */
  /* read word */
  uint16 word;
  uint16 sh = (ofs & 1) << 3;
  word = *(uint16*)(base + (ofs >> 1));
  /* mask bit field */
  word &= ~(0xFF << sh);
  /* put byte into word */
  word |= (0xFF & byte) << sh;
  /* put word back into memory */
  *(uint16*)(base + (ofs >> 1)) = word;
#else
  *(uint8*)(base+ofs) = (uint8) byte;
#endif

}

uint32 GetWord(void* buf, uint32 ofs)
{

  uint32 word;

/* read word depending on width of flash's dbus */
#if defined(__TMS470__) || \
    defined(__TMS320C55X__)

  /* Big endian */
  word = (uint32)GetByte(buf, ofs++);
  if (width >= 1)
    word = (word << 8) | (uint32)GetByte(buf, ofs++);;
  if (width >= 2) {
    word = (word << 8) | (uint32)GetByte(buf, ofs++);;
    word = (word << 8) | (uint32)GetByte(buf, ofs++);;
  }
#else
  /* Little endian*/
  word = (uint32)GetByte(buf, ofs++);
  if (width >= 1)
    word |= ((uint32)GetByte(buf, ofs++)) << 8;
  if (width >= 2) {
    word |= ((uint32)GetByte(buf, ofs++)) << 16;
    word |= ((uint32)GetByte(buf, ofs++)) << 24;
  }
 #endif
  return word;
}


uint16 check_iface_params()
{

  /* xbus_width must be >= word_width */
  /* width must be <= xbus_width */

  if ( xbus_width < word_width ||  /* Not suppoted - two accesses to xbus needed for one word */
       width > xbus_width || /* ??? Flash data bus can't be wider than xbus */
	   width > 2 ||
	   xbus_width > 2 ||
	   word_width > 2) {

	status = STATUS_INVALID_PARAMETER;
    return 0;
  }

  return 1;
}
